import React from "react";
import { Anchor, Grid } from "@lugia/lugia-web";
import EditTables from "../../edit-table";
import FooterNav from "../../footer-nav";
import PageNavHoC from "../../common/PageNavHoC";
import widgetrouter from "../../router/widgetrouter";
import ICON from "@lugia/lugia-web/dist/icon/lugia.icon.zh-CN.json";
import Demo from "../code-box";
import Title from "../code-box/Title";
const BaseIcon = require("./BaseIcon").default;
const DisplayIcon = require("./DisplayIcon").default;

const { Link } = Anchor;
const { Row, Col } = Grid;

export default PageNavHoC(
  widgetrouter,
  class ComDemo extends React.Component {
    handleLinkClick = (e, href) => {
      if (href) {
        const name = href.slice(1);
        const anchorElement = document.getElementById(name);
        if (anchorElement) {
          anchorElement.scrollIntoView({ block: "start", behavior: "smooth" });
        }
      }
    };

    render() {
      const { next, prev, isMobile = false } = this.props;
      const span = isMobile ? 24 : 20;
      const style = isMobile ? {} : { paddingRight: "50px" };
      return (
        <Row>
          <Col span={span}>
            <div style={style}>
              <Title
                title={"图标"}
                subTitle={"Icon"}
                desc={"语义化的矢量图形"}
              />
              <Demo
                title={"图标"}
                titleID={"icon-0"}
                code={
                  <code>{`import React from \"react\";\nimport { Icon, Theme } from \"@lugia/lugia-web\";\nimport Widget from \"@lugia/lugia-web/dist/consts\";\nimport styled from \"styled-components\";\nimport Copy from \"../code-box/Copy\";\nimport colorsFunc from \'@lugia/lugia-web/dist/css/stateColor\';\nconst { themeColor,defaultColor } = colorsFunc();\n\nconst IconWrapper = styled.div\`\n  display: inline-block;\n  &:hover {\n    background: \${themeColor};\n    transform: scale(1.2);\n    > i {\n      color: \${defaultColor};\n    }\n  }\n\n  cursor: pointer;\n  transition: color 0.3s ease-in-out, background-color 0.3s ease-in-out;\n  margin: 5px;\n  border-radius: 4px;\n  background-color: \${defaultColor};\n\`;\nexport default class BaseIcon extends React.Component<any, any> {\n  render() {\n    const view = {\n      [Widget.Icon]: {\n        Icon: {\n          normal: {\n            margin: {\n              left: 10,\n              right: 10,\n              top: 10,\n              bottom: 10\n            },\n            fontSize: 36\n          },\n          hover: {\n            color: \"white\"\n          }\n        }\n      }\n    };\n\n    return (\n      <Theme config={view}>\n        <Copy ref={cmp => (this.copy = cmp)} />\n        <IconWrapper>\n          <Icon\n            iconClass={\"lugia-icon-financial_unlock\"}\n            onClick={() => {\n              this.copy.copy(\"lugia-icon-financial_unlock\");\n            }}\n          />\n        </IconWrapper>\n        <IconWrapper>\n          <Icon\n            iconClass={\"lugia-icon-financial_upload_cloud\"}\n            onClick={() => {\n              this.copy.copy(\"lugia-icon-financial_upload_cloud\");\n            }}\n          />\n        </IconWrapper>\n        <IconWrapper>\n          <Icon\n            iconClass={\"lugia-icon-financial_pay\"}\n            onClick={() => {\n              this.copy.copy(\"lugia-icon-financial_pay\");\n            }}\n          />\n        </IconWrapper>\n      </Theme>\n    );\n  }\n}\n`}</code>
                }
                desc={"语义化的矢量图形"}
                demo={<BaseIcon />}
              ></Demo>
              <Demo
                title={"图标"}
                titleID={"icon-1"}
                code={
                  <code>{`import React from \'react\';\nimport { Icon, Theme, notification } from \'@lugia/lugia-web\';\nimport Widget from \'@lugia/lugia-web/dist/consts\';\nimport styled from \'styled-components\';\nimport Copy from \'../code-box/Copy\';\nimport colorsFunc from \'@lugia/lugia-web/dist/css/stateColor\';\nconst { themeColor,defaultColor } = colorsFunc();\n\nconst directionData = [\n  \'lugia-icon-direction_arrow_down\',\n  \'lugia-icon-direction_arrow_left\',\n  \'lugia-icon-direction_arrow_right\',\n  \'lugia-icon-direction_arrow_up\',\n  \'lugia-icon-direction_arrows_alt\',\n  \'lugia-icon-direction_backtop\',\n  \'lugia-icon-direction_backward\',\n  \'lugia-icon-direction_caret_down\',\n  \'lugia-icon-direction_caret_left\',\n  \'lugia-icon-direction_caret_right\',\n  \'lugia-icon-direction_caret_up\',\n  \'lugia-icon-direction_Center_alignment\',\n  \'lugia-icon-direction_double_left\',\n  \'lugia-icon-direction_double_right\',\n  \'lugia-icon-direction_down_circle_o\',\n  \'lugia-icon-direction_down_circle\',\n  \'lugia-icon-direction_down_square_o\',\n  \'lugia-icon-direction_down-square\',\n  \'lugia-icon-direction_down\',\n  \'lugia-icon-direction_enter_c\',\n  \'lugia-icon-direction_enter\',\n  \'lugia-icon-direction_fast_backward\',\n  \'lugia-icon-direction_fast_forward\',\n  \'lugia-icon-direction_forward\',\n  \'lugia-icon-direction_Left_aligned\',\n  \'lugia-icon-direction_left_circle_o\',\n  \'lugia-icon-direction_left_circle\',\n  \'lugia-icon-direction_left_square_o\',\n  \'lugia-icon-direction_left-square\',\n  \'lugia-icon-direction_Left\',\n  \'lugia-icon-direction_login\',\n  \'lugia-icon-direction_logout\',\n  \'lugia-icon-direction_menu_food\',\n  \'lugia-icon-direction_menu_unfood\',\n  \'lugia-icon-direction_play_circle_o\',\n  \'lugia-icon-direction_play_circle\',\n  \'lugia-icon-direction_retweet\',\n  \'lugia-icon-direction_right_aligned\',\n  \'lugia-icon-direction_right_circle_o\',\n  \'lugia-icon-direction_right_circle\',\n  \'lugia-icon-direction_right_square_o\',\n  \'lugia-icon-direction_right-square\',\n  \'lugia-icon-direction_right\',\n  \'lugia-icon-direction_rollback\',\n  \'lugia-icon-direction_shrink\',\n  \'lugia-icon-direction_step_backward\',\n  \'lugia-icon-direction_step_forward\',\n  \'lugia-icon-direction_swap_left\',\n  \'lugia-icon-direction_swap_right\',\n  \'lugia-icon-direction_swap\',\n  \'lugia-icon-direction_Telescopic\',\n  \'lugia-icon-direction_up_circle_o\',\n  \'lugia-icon-direction_up_circle\',\n  \'lugia-icon-direction_up_square_o\',\n  \'lugia-icon-direction_up-square\',\n  \'lugia-icon-direction_up\',\n  \'lugia-icon-direction_verticle_left\',\n  \'lugia-icon-direction_verticle_right\'\n];\nconst finacialData = [\n  \'lugia-icon-finacial_check_all\',\n  \'lugia-icon-finacial_copy\',\n  \'lugia-icon-finacial_deselection\',\n  \'lugia-icon-finacial_fail\',\n  \'lugia-icon-finacial_half_star\',\n  \'lugia-icon-finacial_hide_code\',\n  \'lugia-icon-financial_abort\',\n  \'lugia-icon-financial_add_pic\',\n  \'lugia-icon-financial_amplification\',\n  \'lugia-icon-financial_archive\',\n  \'lugia-icon-financial_audit\',\n  \'lugia-icon-financial_Back_file\',\n  \'lugia-icon-financial_bank\',\n  \'lugia-icon-financial_bar_code\',\n  \'lugia-icon-financial_bell\',\n  \'lugia-icon-financial_bold\',\n  \'lugia-icon-financial_calculator\',\n  \'lugia-icon-financial_camera\',\n  \'lugia-icon-financial_choose\',\n  \'lugia-icon-financial_classification\',\n  \'lugia-icon-financial_clip\',\n  \'lugia-icon-financial_cloud\',\n  \'lugia-icon-financial_code\',\n  \'lugia-icon-financial_column_width\',\n  \'lugia-icon-financial_columns\',\n  \'lugia-icon-financial_compass\',\n  \'lugia-icon-financial_conference\',\n  \'lugia-icon-financial_contacts\',\n  \'lugia-icon-financial_copy\',\n  \'lugia-icon-financial_credit_card\',\n  \'lugia-icon-financial_database\',\n  \'lugia-icon-financial_date\',\n  \'lugia-icon-financial_delete\',\n  \'lugia-icon-financial_describe\',\n  \'lugia-icon-financial_disconnect\',\n  \'lugia-icon-financial_download_cloud\',\n  \'lugia-icon-financial_download\',\n  \'lugia-icon-financial_e-mail\',\n  \'lugia-icon-financial_editor\',\n  \'lugia-icon-financial_environment\',\n  \'lugia-icon-financial_excle\',\n  \'lugia-icon-financial_export\',\n  \'lugia-icon-financial_file_unknown\',\n  \'lugia-icon-financial_filing_cabinet\',\n  \'lugia-icon-financial_filter\',\n  \'lugia-icon-financial_folder_add\',\n  \'lugia-icon-financial_folder_open\',\n  \'lugia-icon-financial_folder\',\n  \'lugia-icon-financial_font_colors\',\n  \'lugia-icon-financial_font_size\',\n  \'lugia-icon-financial_form\',\n  \'lugia-icon-financial_founder\',\n  \'lugia-icon-financial_framework\',\n  \'lugia-icon-financial_global\',\n  \'lugia-icon-financial_graph\',\n  \'lugia-icon-financial_group\',\n  \'lugia-icon-financial_hard_disk\',\n  \'lugia-icon-financial_head\',\n  \'lugia-icon-financial_heart_o\',\n  \'lugia-icon-financial_heart\',\n  \'lugia-icon-financial_histogram\',\n  \'lugia-icon-financial_home\',\n  \'lugia-icon-financial_Hourglass\',\n  \'lugia-icon-financial_information_c\',\n  \'lugia-icon-financial_information\',\n  \'lugia-icon-financial_italic\',\n  \'lugia-icon-financial_jpg\',\n  \'lugia-icon-financial_key\',\n  \'lugia-icon-financial_layout\',\n  \'lugia-icon-financial_like_o\',\n  \'lugia-icon-financial_like\',\n  \'lugia-icon-financial_line_height\',\n  \'lugia-icon-financial_line\',\n  \'lugia-icon-financial_link\',\n  \'lugia-icon-financial_loading_o\',\n  \'lugia-icon-financial_loading\',\n  \'lugia-icon-financial_lock\',\n  \'lugia-icon-financial_man\',\n  \'lugia-icon-financial_markdown\',\n  \'lugia-icon-financial_meh_o\',\n  \'lugia-icon-financial_meh\',\n  \'lugia-icon-financial_monitoring\',\n  \'lugia-icon-financial_more\',\n  \'lugia-icon-financial_move\',\n  \'lugia-icon-financial_notification\',\n  \'lugia-icon-financial_number\',\n  \'lugia-icon-financial_omit\',\n  \'lugia-icon-financial_ordered_list\',\n  \'lugia-icon-financial_paper_clip\',\n  \'lugia-icon-financial_pay\',\n  \'lugia-icon-financial_pdf\',\n  \'lugia-icon-financial_pic_center\',\n  \'lugia-icon-financial_pic_left\',\n  \'lugia-icon-financial_pic_right\',\n  \'lugia-icon-financial_pic\',\n  \'lugia-icon-financial_pie-chart\',\n  \'lugia-icon-financial_pin\',\n  \'lugia-icon-financial_poweroff\',\n  \'lugia-icon-financial_ppt\',\n  \'lugia-icon-financial_print\',\n  \'lugia-icon-financial_progress\',\n  \'lugia-icon-financial_QR_code\',\n  \'lugia-icon-financial_questionnaire\',\n  \'lugia-icon-financial_release_letter\',\n  \'lugia-icon-financial_release\',\n  \'lugia-icon-financial_remind\',\n  \'lugia-icon-financial_remote_control\',\n  \'lugia-icon-financial_resd\',\n  \'lugia-icon-financial_sad_o\',\n  \'lugia-icon-financial_sad\',\n  \'lugia-icon-financial_safe\',\n  \'lugia-icon-financial_save\',\n  \'lugia-icon-financial_scan\',\n  \'lugia-icon-financial_search\',\n  \'lugia-icon-financial_service\',\n  \'lugia-icon-financial_setting\',\n  \'lugia-icon-financial_share\',\n  \'lugia-icon-financial_shrink\',\n  \'lugia-icon-financial_skin\',\n  \'lugia-icon-financial_smile_o\',\n  \'lugia-icon-financial_smile\',\n  \'lugia-icon-financial_sort_ascending\',\n  \'lugia-icon-financial_sort_descending\',\n  \'lugia-icon-financial_special_focus\',\n  \'lugia-icon-financial_star_o\',\n  \'lugia-icon-financial_star\',\n  \'lugia-icon-financial_statistical_add\',\n  \'lugia-icon-financial_statistics\',\n  \'lugia-icon-financial_strikethrough\',\n  \'lugia-icon-financial_subtasks\',\n  \'lugia-icon-financial_switch_e_and_c\',\n  \'lugia-icon-financial_table\',\n  \'lugia-icon-financial_tag\',\n  \'lugia-icon-financial_tags\',\n  \'lugia-icon-financial_text\',\n  \'lugia-icon-financial_tools\',\n  \'lugia-icon-financial_transfer_i\',\n  \'lugia-icon-financial_transfer_u\',\n  \'lugia-icon-financial_underline\',\n  \'lugia-icon-financial_unlike_o\',\n  \'lugia-icon-financial_unlike\',\n  \'lugia-icon-financial_unlock\',\n  \'lugia-icon-financial_unordered_list\',\n  \'lugia-icon-financial_upload_cloud\',\n  \'lugia-icon-financial_upload\',\n  \'lugia-icon-financial_usb\',\n  \'lugia-icon-financial_user\',\n  \'lugia-icon-financial_video_camera\',\n  \'lugia-icon-financial_voice_z\',\n  \'lugia-icon-financial_voice\',\n  \'lugia-icon-financial_wallet\',\n  \'lugia-icon-financial_warnings\',\n  \'lugia-icon-financial_wifi\',\n  \'lugia-icon-financial_women\',\n  \'lugia-icon-financial_word\'\n];\nconst logoData = [\n  \'lugia-icon-logo_aliyun\',\n  \'lugia-icon-logo_android_o\',\n  \'lugia-icon-logo_android\',\n  \'lugia-icon-logo_apple_o\',\n  \'lugia-icon-logo_apple\',\n  \'lugia-icon-logo_baidu\',\n  \'lugia-icon-logo_behance\',\n  \'lugia-icon-logo_chrome\',\n  \'lugia-icon-logo_codepen_ciecle\',\n  \'lugia-icon-logo_codepen\',\n  \'lugia-icon-logo_csswizardry\',\n  \'lugia-icon-logo_datastream\',\n  \'lugia-icon-logo_dingding_circle\',\n  \'lugia-icon-logo_dingding\',\n  \'lugia-icon-logo_dribbble\',\n  \'lugia-icon-logo_dropbox\',\n  \'lugia-icon-logo_facebook\',\n  \'lugia-icon-logo_github\',\n  \'lugia-icon-logo_gitlab\',\n  \'lugia-icon-logo_google_plus\',\n  \'lugia-icon-logo_google\',\n  \'lugia-icon-logo_henghe\',\n  \'lugia-icon-logo_html5\',\n  \'lugia-icon-logo_ie\',\n  \'lugia-icon-logo_instagram\',\n  \'lugia-icon-logo_linkedin\',\n  \'lugia-icon-logo_lugia\',\n  \'lugia-icon-logo_medium\',\n  \'lugia-icon-logo_QQ\',\n  \'lugia-icon-logo_skype\',\n  \'lugia-icon-logo_twitter\',\n  \'lugia-icon-logo_visa\',\n  \'lugia-icon-logo_wechat\',\n  \'lugia-icon-logo_weibo_circle\',\n  \'lugia-icon-logo_weibo\',\n  \'lugia-icon-logo_windows_o\',\n  \'lugia-icon-logo_windows\',\n  \'lugia-icon-logo_ysstech\',\n  \'lugia-icon-logo_zhifubao_circle\',\n  \'lugia-icon-logo_zhifubao\'\n];\nconst reminderData = [\n  \'lugia-icon-reminder_refresh\',\n  \'lugia-icon-reminder_ban\',\n  \'lugia-icon-reminder_check_circle_o\',\n  \'lugia-icon-reminder_check_circle\',\n  \'lugia-icon-reminder_check_square_o\',\n  \'lugia-icon-reminder_check_square\',\n  \'lugia-icon-reminder_check\',\n  \'lugia-icon-reminder_clock_circle_o\',\n  \'lugia-icon-reminder_clock_circle\',\n  \'lugia-icon-reminder_close_circle_o\',\n  \'lugia-icon-reminder_close_circle\',\n  \'lugia-icon-reminder_close_square_o\',\n  \'lugia-icon-reminder_close_square\',\n  \'lugia-icon-reminder_close\',\n  \'lugia-icon-reminder_exclamation_circle_o\',\n  \'lugia-icon-reminder_exclamation_circle\',\n  \'lugia-icon-reminder_exclamation\',\n  \'lugia-icon-reminder_info_circle_o\',\n  \'lugia-icon-reminder_info_circle\',\n  \'lugia-icon-reminder_info\',\n  \'lugia-icon-reminder_minus_circle_o\',\n  \'lugia-icon-reminder_minus_circle\',\n  \'lugia-icon-reminder_minus_square_o\',\n  \'lugia-icon-reminder_minus_square\',\n  \'lugia-icon-reminder_minus\',\n  \'lugia-icon-reminder_pause_circle_o\',\n  \'lugia-icon-reminder_pause_circle\',\n  \'lugia-icon-reminder_pause_cycle\',\n  \'lugia-icon-reminder_pause\',\n  \'lugia-icon-reminder_plus_circle_o\',\n  \'lugia-icon-reminder_plus_circle\',\n  \'lugia-icon-reminder_plus_square_o\',\n  \'lugia-icon-reminder_plus_square\',\n  \'lugia-icon-reminder_plus\',\n  \'lugia-icon-reminder_question_circle_o\',\n  \'lugia-icon-reminder_question_circle\',\n  \'lugia-icon-reminder_question\',\n  \'lugia-icon-reminder_replay\',\n  \'lugia-icon-reminder_square_o\',\n  \'lugia-icon-reminder_warning\'\n];\nconst IconWrapper = styled.div\`\n  display: inline-block;\n  &:hover {\n    background: \${themeColor};\n    transform: scale(1.2);\n    > i {\n      color: \${defaultColor};\n    }\n  }\n  \n  cursor: pointer;\n  transition: color 0.3s ease-in-out, background-color 0.3s ease-in-out;\n  margin: 5px;\n  border-radius: 4px;\n  background-color: \${defaultColor};\n\`;\n\n\nexport default class BaseIcon extends React.Component<any, any> {\n  getIcon = iconClassArray => {\n    let iconClass = \'\';\n    const iconArray = iconClassArray.map(v => {\n      iconClass = v;\n      return iconClass ? (\n        <IconWrapper>\n          <Icon\n            iconClass={iconClass}\n            onClick={() => {\n              this.copy.copy(v);\n            }}\n          />\n        </IconWrapper>\n      ) : null;\n    });\n    return iconArray;\n  };\n  render() {\n    const view = {\n      [Widget.Icon]: {\n        Icon: {\n          normal: {\n            margin: {\n              left: 10,\n              right: 10,\n              top: 10,\n              bottom: 10\n            },\n            fontSize: 36\n          },\n          hover: {\n            color: \'white\',\n          },\n        }\n      }\n    };\n    return (\n      <Theme config={view}>\n        <Copy ref={cmp => (this.copy = cmp)}/>\n        <h2>方向图标</h2>\n        {this.getIcon(directionData)}\n        <h2>指示图标</h2>\n        {this.getIcon(finacialData)}\n        <h2>提示图标</h2>\n        {this.getIcon(reminderData)}\n        <h2>品牌图标</h2>\n        {this.getIcon(logoData)}\n      </Theme>\n    );\n  }\n}\n`}</code>
                }
                desc={"语义化的矢量图形,点击可以复制代码"}
                demo={<DisplayIcon />}
              ></Demo>
              <EditTables dataSource={ICON} />
              <FooterNav prev={prev} next={next} />
            </div>
          </Col>
          {!isMobile && (
            <Col span={4}>
              <Anchor
                slideType="line"
                onClick={this.handleLinkClick}
                useHref={false}
              >
                <Link title={"图标"} href={"#icon-0"} />
                <Link title={"图标"} href={"#icon-1"} />
              </Anchor>
            </Col>
          )}
        </Row>
      );
    }
  }
);
